/*----------------------------------------------------------------------------
;
; winpf.h -- ?printf() replacements using Windows user32 wvsprintf()
;
; Tiny w_xxx "printf" functions to replace equivalent C runtime versions.
; Written to minimize code size by using direct Windows wvsprintf() call.
;
; Differences/notes:
;	(1) functions that output do so in _O_TEXT mode (ie \n expands \r\n).
;	(2) no float format support.
;	(3) output size limited to 1k.
;	(4) handles are Win HANDLE type, not stdio FILE (not stdin/stdout).
;		one of the defined W_STD... constants can be used as handle arg.
;
;	Date	Programmer	Description
;	------	----------	-----------
;	170325	Paul Houle	Initial creation, source at paulhoule.com
;
;---------------------------------------------------------------------------*/

#ifndef _WINPF_DEFINED					// include guard
#define _WINPF_DEFINED

#include <stdarg.h>
#include <windows.h>

#define W_STDIN  (void *) (size_t) (short) STD_INPUT_HANDLE
#define W_STDOUT (void *) (size_t) (short) STD_OUTPUT_HANDLE
#define W_STDERR (void *) (size_t) (short) STD_ERROR_HANDLE

int w_printf(char *pFmt, ...);
int w_sprintf(char *pOut, char *pFmt, ...);
int w_fprintf(HANDLE h, char *pFmt, ...);
int w_vfprintf(HANDLE h, char *pFmt, va_list vl);

#endif
